import unittest
import modpipe.test
from modpipe.src import ConvertSeq
import os

class ConvertSeqTests(modpipe.test.TestCase):

    def _check_fasta(self, outfile, code, seq):
        lines = file(outfile).readlines()
        self.assertEqual(len(lines), 2)
        self.assertEqual(lines[0].rstrip(), '>' + code)
        self.assertEqual(lines[1].rstrip(), seq)
        os.unlink(outfile)

    def _check_pir(self, outfile, code, seq):
        lines = file(outfile).readlines()
        self.assertEqual(len(lines), 4)
        self.assertEqual(lines[0].rstrip(), '>P1;' + code)
        self.assertEqual(lines[1].rstrip(), 'sequence:::::::::')
        self.assertEqual(lines[2].rstrip(), seq)
        self.assertEqual(lines[3].rstrip(), '*')
        os.unlink(outfile)

    def _write_pir(self, infile, code, seq):
        f = file(infile, 'w')
        print >> f, "C; comment1"
        print >> f, "R; comment2"
        print >> f, ">P1;" + code
        print >> f, "structureX:bar:1:A:106:A:bar:baz: 1.90: 0.19"
        print >> f, seq + "*"

    def _write_fasta(self, infile, code, seq):
        f = file(infile, 'w')
        print >> f, ">" + code
        print >> f, seq

    def test_pir_to_fasta(self):
        """Check conversion of PIR sequences to FASTA"""
        infile = 'infile'
        outfile = 'outfile'
        code = 'foo'
        for seq in ('MLGIIM', 'MLGiIm', 'MLGI IM'):
            self._write_pir(infile, code, seq)
            self.run_script('src', ConvertSeq,
                            ['-o', outfile, '-f', 'PIR', '-g', 'FASTA', infile])
            os.unlink(infile)
            self._check_fasta(outfile, code, 'MLGIIM')

    def test_fasta_to_pir(self):
        """Check conversion of FASTA sequences to PIR"""
        infile = 'infile'
        outfile = 'outfile'
        code = 'bar'
        for seq in ('CLGIIM', 'CLGiIm', 'CLGI IM'):
            self._write_fasta(infile, code, seq)
            self.run_script('src', ConvertSeq,
                            ['-o', outfile, '-f', 'FASTA', '-g', 'PIR', infile])
            os.unlink(infile)
            self._check_pir(outfile, code, 'CLGIIM')

if __name__ == '__main__':
    unittest.main()
